providers/responsive_provider library
Classes
- ResponsiveProvider
-
The
ResponsiveProviderclass is a provider that listens for changes in device metrics and screen dimensions. It allows adapting the UI based on the current screen size and device type, using breakpoints.