isBigger method

bool isBigger(
  1. Breakpoint b
)

Compares the current breakpoint with another and returns true if the current breakpoint is larger than the provided breakpoint.

Implementation

bool isBigger(Breakpoint b) {
  return toSize > b.toSize;
}