isComputer method
Checks if the current breakpoint corresponds to a computer device.
Implementation
bool isComputer() {
return computer.contains(this);
}
Checks if the current breakpoint corresponds to a computer device.
bool isComputer() {
return computer.contains(this);
}