isPhone method
Checks if the current breakpoint corresponds to a phone device.
Implementation
bool isPhone() {
return phone.contains(this);
}
Checks if the current breakpoint corresponds to a phone device.
bool isPhone() {
return phone.contains(this);
}