isTablet method
Checks if the current breakpoint corresponds to a tablet device.
Implementation
bool isTablet() {
return tablet.contains(this);
}
Checks if the current breakpoint corresponds to a tablet device.
bool isTablet() {
return tablet.contains(this);
}