BreakpointValue<T> class
A helper class that allows assigning values based on the current device type (phone, tablet, or computer).
Example usage:
final BreakpointValue<int> breakpointValue = BreakpointValue(
phone: 1,
tablet: 2,
computer: 3,
);
Constructors
- BreakpointValue({T? phone, T? tablet, T? computer})
- Constructor that assigns values to be used depending on the device type.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited