widgets/responsive_scaffold library

Classes

ResponsiveScaffold
A scaffold widget that adapts to different screen sizes. It wraps the content in a responsive context using ResponsiveProvider.
ResponsiveScaffoldRender
Renders the actual scaffold layout for the ResponsiveScaffold. This class builds a standard Scaffold but allows options like extending the body and controlling whether the body should resize to avoid the keyboard.