ResponsiveScaffold class

A scaffold widget that adapts to different screen sizes. It wraps the content in a responsive context using ResponsiveProvider.

Inheritance

Constructors

ResponsiveScaffold({Key? key, PreferredSizeWidget? appBar, Widget? drawer, Widget? child, Widget? bottomNavigationBar, Widget? floatingActionButton})
const

Properties

appBar PreferredSizeWidget?
An optional AppBar to be displayed at the top of the scaffold.
final
bottomNavigationBar Widget?
An optional bottom navigation bar widget.
final
child Widget?
The main content of the scaffold.
final
drawer Widget?
An optional drawer widget to be displayed on the side of the scaffold.
final
floatingActionButton Widget?
An optional floating action button widget.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ResponsiveScaffold>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → _ResponsiveScaffoldState
Static method to access the state of the nearest ResponsiveScaffold ancestor in the widget tree.