ResponsiveScaffoldRender class

Renders the actual scaffold layout for the ResponsiveScaffold. This class builds a standard Scaffold but allows options like extending the body and controlling whether the body should resize to avoid the keyboard.

Inheritance

Constructors

ResponsiveScaffoldRender({Key? key, PreferredSizeWidget? appBar, Widget? drawer, Widget? child, Widget? bottomNavigationBar, Widget? floatingActionButton, bool resizeToAvoidBottomInset = true, bool extendBody = true})
const

Properties

appBar PreferredSizeWidget?
final
bottomNavigationBar Widget?
final
child Widget?
final
drawer Widget?
final
extendBody bool
Whether the scaffold should extend the body behind the app bar.
final
floatingActionButton Widget?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
resizeToAvoidBottomInset bool
Whether the scaffold should resize to avoid the on-screen keyboard.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited