resizeToAvoidBottomInset property
Whether the scaffold should resize to avoid the on-screen keyboard.
Implementation
final bool resizeToAvoidBottomInset;
Whether the scaffold should resize to avoid the on-screen keyboard.
final bool resizeToAvoidBottomInset;