ResponsiveWrap class
A widget that wraps its children and adapts their size based on the available screen space. The widget allows for flexible width, height, and size boundaries, making it suitable for responsive layouts.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ResponsiveWrap
Constructors
-
ResponsiveWrap({Key? key, required List<
Widget> children, EdgeInsets padding = const EdgeInsets.all(0.0), double flexWidth = 1.0, double flexHeight = 1.0, double suggestedHeight = 0.0, double suggestedWidth = 0.0, (double, double) boundariesHeight = (0.0, double.infinity), (double, double) boundariesWidth = (0.0, double.infinity)}) -
const
Properties
- boundariesHeight → (double, double)
-
Boundaries for the height of the children in the format (min, max).
final
- boundariesWidth → (double, double)
-
Boundaries for the width of the children in the format (min, max).
final
-
children
→ List<
Widget> -
The list of widgets to be wrapped.
final
- flexHeight → double
-
The flex factor for the height of the wrapped children.
final
- flexWidth → double
-
The flex factor for the width of the wrapped children.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsets
-
Padding to be applied around each child widget.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedHeight → double
-
A suggested height to use when there are no height constraints.
final
- suggestedWidth → double
-
A suggested width to use when there are no width constraints.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
doBoundaries(
double width, (double, double) boundaries) → double - Ensures that the width is within the specified boundaries.
-
hiearchy(
BuildContext context, List< Widget> children) → Widget -
Builds the layout using a
LayoutBuilderto dynamically adjust the size of the children based on the available constraints. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited