ResponsiveProvider class
The ResponsiveProvider class is a provider that listens for changes in
device metrics and screen dimensions. It allows adapting the UI based on
the current screen size and device type, using breakpoints.
- Inheritance
-
- Object
- ChangeNotifier
- ResponsiveProvider
- Implemented types
Constructors
- ResponsiveProvider()
- Constructor that initializes the provider and adds this instance as an observer to monitor changes in the device metrics.
Properties
- breakpoint ↔ Breakpoint
-
getter/setter pair
- devicePixelRatio ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- height → double
-
Gets the current screen height.
no setter
- physicalHeight ↔ double
-
getter/setter pair
- physicalWidth ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenHeight ↔ double
-
getter/setter pair
- screenWidth ↔ double
-
getter/setter pair
- width → double
-
Gets the current screen width.
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
override
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
override
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
override
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
override
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
override
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
override
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
override
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
override
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
override
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
override
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
override
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
override
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
override
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
override
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
override
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
showWhen(
Breakpoint md, Widget widget) → Widget - Conditionally shows a widget based on the current breakpoint.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void - Updates the screen size and breakpoint based on the current device's metrics (physical size and pixel ratio). It calculates the screen width and height in logical pixels and determines the appropriate breakpoint.
-
value<
T> ({required List< Breakpoint> when, required T value, required T ifnot}) → T - Returns a value based on the current device type.
-
valueWhen<
T> (T value, Breakpoint md, T newValue) → T -
Returns a new value based on the current breakpoint. The new value will
be returned if the breakpoint is greater than or equal to the specified
mdbreakpoint. -
when<
T> (T? phone, T? tablet, T? computer) → T - Returns a value based on the current device type.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited