Breakpoint enum
Enum that represents different breakpoints for responsive design. Each breakpoint corresponds to a specific screen width.
- Inheritance
- Available extensions
Values
- xs → const Breakpoint
- sm → const Breakpoint
- md → const Breakpoint
- lg → const Breakpoint
- xl → const Breakpoint
- xxl → const Breakpoint
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toSize → double
-
Available on Breakpoint, provided by the BreakpointExtensions extension
Converts aBreakpointto its corresponding screen width in pixels.no setter - toText → String
-
Available on Breakpoint, provided by the BreakpointExtensions extension
Converts aBreakpointto its textual representation.no setter
Methods
-
isBigger(
Breakpoint b) → bool -
Available on Breakpoint, provided by the BreakpointExtensions extension
Compares the current breakpoint with another and returnstrueif the current breakpoint is larger than the provided breakpoint. -
isComputer(
) → bool -
Available on Breakpoint, provided by the BreakpointExtensions extension
Checks if the current breakpoint corresponds to a computer device. -
isPhone(
) → bool -
Available on Breakpoint, provided by the BreakpointExtensions extension
Checks if the current breakpoint corresponds to a phone device. -
isTablet(
) → bool -
Available on Breakpoint, provided by the BreakpointExtensions extension
Checks if the current breakpoint corresponds to a tablet device. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Breakpoint> - A constant List of the values in this enum, in order of their declaration.