BreakpointExtensions extension

Extension methods for the Breakpoint enum to provide additional functionality such as converting breakpoints to screen sizes, checking device type, and comparing breakpoints.

on

Properties

toSize double

Available on Breakpoint, provided by the BreakpointExtensions extension

Converts a Breakpoint to its corresponding screen width in pixels.
no setter
toText String

Available on Breakpoint, provided by the BreakpointExtensions extension

Converts a Breakpoint to its textual representation.
no setter

Methods

isBigger(Breakpoint b) bool

Available on Breakpoint, provided by the BreakpointExtensions extension

Compares the current breakpoint with another and returns true if the current breakpoint is larger than the provided breakpoint.
isComputer() bool

Available on Breakpoint, provided by the BreakpointExtensions extension

Checks if the current breakpoint corresponds to a computer device.
isPhone() bool

Available on Breakpoint, provided by the BreakpointExtensions extension

Checks if the current breakpoint corresponds to a phone device.
isTablet() bool

Available on Breakpoint, provided by the BreakpointExtensions extension

Checks if the current breakpoint corresponds to a tablet device.

Constants

computer → const List<Breakpoint>
Defines the breakpoints that correspond to computers.
phone → const List<Breakpoint>
Defines the breakpoints that correspond to phones.
tablet → const List<Breakpoint>
Defines the breakpoints that correspond to tablets.