isBigger method
Compares the current breakpoint with another and returns true if
the current breakpoint is larger than the provided breakpoint.
Implementation
bool isBigger(Breakpoint b) {
return toSize > b.toSize;
}
Compares the current breakpoint with another and returns true if
the current breakpoint is larger than the provided breakpoint.
bool isBigger(Breakpoint b) {
return toSize > b.toSize;
}