BreakpointValue<T> class

A helper class that allows assigning values based on the current device type (phone, tablet, or computer).

Example usage:

final BreakpointValue<int> breakpointValue = BreakpointValue(
  phone: 1,
  tablet: 2,
  computer: 3,
);

Constructors

BreakpointValue({T? phone, T? tablet, T? computer})
Constructor that assigns values to be used depending on the device type.

Properties

computer → T?
final
hashCode int
The hash code for this object.
no setterinherited
phone → T?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet → T?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited